@@ -16,7 +16,6 @@
 # -*- coding: utf-8 -*-
 """
 Module usage:
-- splunk_appinspect: To parse the configuration files from Add-on package
 - helmut : To connect to a Splunk instance. source: splunk-sdk
 - helmut_lib: Provides various Utility functions to search on Splunk. Source: splunk-sdk
 """
@@ -880,10 +879,7 @@ def is_responsive_hec(request, splunk):
             "Trying to connect Splunk HEC...  splunk=%s",
             json.dumps(splunk),
         )
-        session_headers = {
-            "Authorization": f'Splunk {request.config.getoption("splunk_hec_token")}'
-        }
-        response = requests.get(
+        response = requests.get(  # nosemgrep: splunk.disabled-cert-validation
             f'{request.config.getoption("splunk_hec_scheme")}://{splunk["forwarder_host"]}:{splunk["port_hec"]}/services/collector/health/1.0',
             verify=False,
         )
@@ -891,8 +887,7 @@ def is_responsive_hec(request, splunk):
         if response.status_code in (200, 201):
             LOGGER.info("Splunk HEC is responsive.")
             return True
-        else:
-            return False
+        return False
     except Exception as e:
         LOGGER.warning(
             "Could not connect to Splunk HEC. Will try again. exception=%s",
